#
# spec file for package openwsman
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1140 || 0%{?fedora_version} > 14
%define has_systemd 1
%else
%define has_systemd 0
%endif

%if 0%{?suse_version} > 1500 || 0%{?fedora_version} > 14
%define has_firewalld 1
%else
%define has_firewalld 0
%endif

%if 0%{?suse_version} >= 1500
%define want_python3 1
%else
%define want_python3 0
%endif

Name:           openwsman
BuildRequires:  cmake >= 3.12
BuildRequires:  cunit-devel
BuildRequires:  gcc-c++
BuildRequires:  libxml2-devel
BuildRequires:  pam-devel
BuildRequires:  sblim-sfcc-devel
BuildRequires:  swig >= 2.0.5

BuildRequires:  perl
%if 0%{?want_python3}
BuildRequires:  python3-devel
%else
BuildRequires:  python-devel
%endif

%if 0%{?rhel_version} > 0
#!BuildIgnore:  vim
%endif

%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
BuildRequires:  curl-devel

%if 0%{?fedora} == 16 || (0%{?centos_version}>=500 && 0%{?centos_version}<700) || (0%{?rhel_version}>=500 && 0%{?rhel_version}<700)
BuildRequires:  java-1.6.0-openjdk-devel
%else
%if (0%{?fedora} >= 17 && 0%{?fedora} < 22) || 0%{?centos_version} >= 700 || 0%{?rhel_version} >= 700
BuildRequires:  java-1.7.0-openjdk-devel
%else
BuildRequires:  java-devel
%endif
%endif

BuildRequires:  openssl-3-devel
BuildRequires:  pkgconfig
BuildRequires:  ruby

%if 0%{?fedora} + 0%{?rhel_version} + 0%{?centos_version}  > 0

%if 0%{?rhel_version} < 700
BuildRequires:  ruby-devel
%endif

BuildRequires:  ruby-libs

%endif

%if 0%{?rhel_version} >= 700 || 0%{?centos_version} >= 700 || 0%{?fedora} > 16
BuildRequires:  rubygem-rdoc
%else
BuildRequires:  ruby-rdoc
%endif

%if 0%{?fedora} > 18
BuildRequires:  rubypick
%endif

%if 0%{?fedora} > 0 || 0%{?rhel_version} >= 600  || 0%{?centos_version} >= 600
BuildRequires:  perl-devel
%endif
%endif

%if 0%{?suse_version} > 0
BuildRequires:  java-devel
# No jni_md.h on SLE10 :-/
#%%if 0%%{?suse_version} < 1100
#BuildRequires:  java-1_5_0-ibm-devel
#BuildRequires:  libgcj-devel
#BuildRequires:  update-alternatives
#%%endif

%if 0%{?suse_version} > 1500
BuildRequires:  strip-nondeterminism
%endif
%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
BuildRequires:  libcurl-devel
BuildRequires:  libopenssl-devel
%else
# SLE10
BuildRequires:  curl-devel
BuildRequires:  libidn-devel
BuildRequires:  openssl-devel
%endif

%if 0%{?suse_version} > 910
%if 0%{?suse_version} < 1110
# SLE 10 has Ruby 1.8.6 and runs into http://help.rubygems.org/discussions/problems/859-trying-to-install-rubygems
BuildRequires:  rubygems <= 1.3.7
%else
BuildRequires:  rubygems
%endif
BuildRequires:  pkg-config
BuildRequires:  ruby-devel
%else
# SLE9
BuildRequires:  pkgconfig
BuildRequires:  ruby
%endif

%endif

%if 0%{?has_systemd}
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%endif

%if 0%{?has_firewalld}
BuildRequires:  firewall-macros
%endif

Requires(pre):  sed coreutils grep /bin/hostname
Version:        2.8.1
Release:        2.2
# Mandriva:
# Release %%mkrel 1
URL:            http://www.openwsman.org/
Summary:        An implementation of the WS-MAN specification
License:        BSD-3-Clause AND GPL-2.0-only
Group:          System/Management
Source:         %{name}-%{version}.tar.bz2
Source1:        %{name}.rpmlintrc
Source21:       %{name}.pam.rh
Source22:       %{name}.pam
Patch1:         openwsman-redhat-initscript.patch
# https://github.com/Openwsman/openwsman/commit/e619555c3484264a188396bc8b9c77c39ef47bb2
Patch2:         openwsman-gcc15.patch
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
%define pamfile %{S:21}
%else
%define pamfile %{S:22}
%endif
Source3:        %{name}.SuSEfirewall2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source4:        %{name}.service
Source5:        %{name}.firewalld

%description
OpenWSMAN is an implementation of the WS-Management protocol stack.
Web Services for Management (WS-MAN) is a specification for managing
computer systems using web services standards.

%package -n libwsman1
Summary:        An implementation of the WS-MAN specification
Group:          System/Libraries
Conflicts:      libwsman3

%description -n libwsman1
OpenWSMAN is an implementation of the WS-Management protocol stack.
Web Services for Management (WS-MAN) is a specification for managing
computer systems using web services standards.

This subpackage provides the common libraries of OpenWSMAN.

%package -n libwsman_client5
Summary:        An implementation of the WS-MAN specification
Group:          System/Libraries

%description -n libwsman_client5
OpenWSMAN is an implementation of the WS-Management protocol stack.
Web Services for Management (WS-MAN) is a specification for managing
computer systems using web services standards.

This subpackage provides the client libraries of OpenWSMAN.

%package -n libwsman-devel
Summary:        Development files for OpenWSMAN
Group:          Development/Libraries/C and C++
Provides:       openwsman-devel = %{version}
Obsoletes:      openwsman-devel < %{version}
Requires:       %{name}-server = %{version}
Requires:       libwsman1 = %{version}-%{release}
Requires:       libwsman_client5 = %{version}-%{release}
Requires:       libxml2-devel
Requires:       pam-devel
Requires:       sblim-sfcc-devel

%description -n libwsman-devel
OpenWSMAN is an implementation of the WS-Management protocol stack.

This subpackage provides the header files for its libraries.

%package -n libwsman_clientpp1
Summary:        C++ bindings to the OpenWSMAN client library
Group:          System/Libraries
Provides:       openwsman-client = %{version}
Obsoletes:      openwsman-client < %{version}

%description -n libwsman_clientpp1
OpenWSMAN is an implementation of the WS-Management protocol stack.

This subpackage provides a C++ API library for OpenWSMAN.

%package -n libwsman_clientpp-devel
Summary:        C++ development files for OpenWSMAN
Group:          Development/Libraries/C and C++
Requires:       libwsman-devel = %{version}
Requires:       libwsman_clientpp1 = %{version}

%description -n libwsman_clientpp-devel
OpenWSMAN is an implementation of the WS-Management protocol stack.

Development files for the C++ interface to the OpenWSMAN client library.

%package server
Requires(pre):  sed coreutils grep diffutils /bin/hostname
%if 0%{?suse_version}
Requires(pre):  fillup
%endif
Summary:        OpenWSMAN server and service libraries
Group:          System/Management

%description server
OpenWSMAN server and service libraries.

%package server-plugin-ruby
Requires:       openwsman-server
Summary:        OpenWSMAN Server Plugin for Ruby extensions
Group:          System/Management

%description server-plugin-ruby
This package provides a OpenWSMAN server plugin to write a
WS-Management resource handler in Ruby.

%if 0%{?want_python3}
%package -n python3-%{name}
Summary:        Python3 bindings for OpenWSMAN client API
Group:          Development/Libraries/Python
Provides:       %{name}-python
%{!?python3_sitelib: %global python3_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python3_sitearch: %global python3_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%{!?py3_requires: %define py3_requires Requires: python3}
%{py3_requires}

%description -n python3-%{name}
This package provides Python3 bindings to access the OpenWSMAN client
API.

%else

%package python
Summary:        Python bindings for OpenWSMAN client API
Group:          Development/Libraries/Python
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%{!?py_requires: %define py_requires Requires: python}
%{py_requires}

%description python
This package provides Python bindings to access the OpenWSMAN client
API.

%endif

# RHEL7 does not have ruby-devel
%if 0%{?rhel_version} != 700

%package ruby
Requires:       ruby

# RbConfig::CONFIG["ruby_version"] is empty in Fedora > 18 !?
%if 0%{?fedora} > 18 || 0%{?rhel_version} >= 700 || 0%{?centos_version} >= 700
%{!?ruby_version: %global ruby_version %(ruby -r rbconfig -e 'print(RbConfig::CONFIG["RUBY_PROGRAM_VERSION"])')}
%else
%{!?ruby_version: %global ruby_version %(ruby -r rbconfig -e 'print(RbConfig::CONFIG["ruby_version"])')}
%endif

%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
Requires:       ruby(abi) = %{ruby_version}
%endif

%if 0%{?suse_version} > 1120
Requires:       ruby(abi) = %{ruby_version}
%endif

%if 0%{?suse_version} == 1010
%{!?ruby_sitelib: %global ruby_sitelib %(ruby -r rbconfig -e 'vd = RbConfig::CONFIG["vendorlibdir"]; print(vd ? vd : RbConfig::CONFIG["sitelibdir"])')}
%{!?ruby_sitearch: %global ruby_sitearch %(ruby -r rbconfig -e 'vad = RbConfig::CONFIG["vendorarchdir"]; print(vad ? vad : RbConfig::CONFIG["sitearchdir"])')}
%else
# SLES 10 can't parse this :-/
%if 0%{?ruby_sitelib} == 0
%if (0%{?fedora} && 0%{?fedora} < 16) || (0%{?centos_version} && 0%{?centos_version}<600) || (0%{?rhel_version} && 0%{?rhel_version}<500)
# Fedora15, RHEL-5 and CentOS-5 don't have vendor lib
# CMAKE checks for "ruby -r vendor-specific" and fails
%{!?ruby_sitelib: %global ruby_sitelib %(ruby -r rbconfig -e 'print(RbConfig::CONFIG["sitelibdir"])')}
%{!?ruby_sitearch: %global ruby_sitearch %(ruby -r rbconfig -e 'print(RbConfig::CONFIG["sitearchdir"])')}
%else
%{!?ruby_sitelib: %global ruby_sitelib %(ruby -r rbconfig -e 'vd = RbConfig::CONFIG["vendorlibdir"]; print(vd ? vd : RbConfig::CONFIG["sitelibdir"])')}
%{!?ruby_sitearch: %global ruby_sitearch %(ruby -r rbconfig -e 'vad = RbConfig::CONFIG["vendorarchdir"]; print(vad ? vad : RbConfig::CONFIG["sitearchdir"])')}
%endif
%endif
%endif

Summary:        Ruby bindings for OpenWSMAN client API
Group:          System/Management

%description ruby
This package provides Ruby bindings to access the OpenWSMAN client API.

%package ruby-docs
Summary:        HTML documentation for OpenWSMAN Ruby bindings
Group:          Documentation/HTML
BuildArch:      noarch

%description ruby-docs
This package provides HTML documentation for the OpenWSMAN Ruby
bindings.

# - endif not rhel7
%endif

%package perl
%if 0%{?fedora}
%define perl_version %(eval "`%{__perl} -V:version`"; echo $version)
%define perl_requires perl(:MODULE_COMPAT_%{perl_version})
Requires:       %{perl_requires}
%else
Requires:       perl = %{perl_version}
%endif
Summary:        Perl bindings for OpenWSMAN client API
Group:          System/Management

%description perl
This package provides Perl bindings to access the OpenWSMAN client API.


%if 0%{?suse_version} == 0 || 0%{?suse_version} >= 1100

%package java
Requires:       java
Requires:       libwsman1 = %{version}
Summary:        Java bindings for OpenWSMAN client API
Group:          System/Management
BuildArch:      noarch

%description java
This package provides Java bindings to access the OpenWSMAN client API.


%endif

# RHEL7 does not have ruby-devel
%if 0%{?rhel_version} != 700
%package -n winrs
Summary:        Windows Remote Shell
Group:          System/Management
Requires:       openwsman-ruby = %{version}
BuildArch:      noarch

%description -n winrs
This is a command line tool for the Windows Remote Shell protocol.
It can be used to send shell commands to remote Windows hosts.

%endif

%prep
%setup -q
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
%patch -P 1 -p1
%endif
%patch -P 2 -p1

%build
rm -rf build
mkdir build
%if 0%{?fedora}
# [ curl-Bugs-1924441 ] SSL callback option with NSS-linked libcurl
# CURLOPT_SSL_CTX_FUNCTION is defined, but does not work on e.g. Fedora
export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -DNO_SSL_CALLBACK"
%endif
# SLES 10 needs explicit java bytecode target
%if 0%{?suse_version} == 1010 || 0%{?suse_version} == 1110
export EXPLICIT_SOURCE=1.5
export EXPLICIT_TARGET=1.5
%endif

cd build
# SLE 10 Java doesn't like EXPLICIT_TARGET any more, disable
cmake \
  -DCMAKE_INSTALL_PREFIX=/usr \
%if 0%{?suse_version} == 1010
  -DBUILD_JAVA=FALSE \
%endif
%if 0%{?want_python3}
  -DBUILD_PYTHON=FALSE \
  -DBUILD_PYTHON3=TRUE \
%else
  -DBUILD_PYTHON=TRUE \
  -DBUILD_PYTHON3=FALSE \
%endif
  -DCMAKE_VERBOSE_MAKEFILE=TRUE \
  -DCMAKE_BUILD_TYPE=Release \
  -DCMAKE_C_FLAGS_RELEASE:STRING="$RPM_OPT_FLAGS -fno-strict-aliasing" \
  -DCMAKE_CXX_FLAGS_RELEASE:STRING="$RPM_OPT_FLAGS" \
  -DCMAKE_SKIP_RPATH=1 \
  -DPACKAGE_ARCHITECTURE=`uname -m` \
  -DEXPLICIT_SOURCE="$EXPLICIT_SOURCE" \
  -DEXPLICIT_TARGET="$EXPLICIT_TARGET" \
  -DLIB=%{_lib} \
  -DBUILD_RUBY_GEM=no \
  -DBUILD_CUNIT_TESTS=on \
  ..

make %{?_smp_mflags}

%install
%cmake_install
mkdir -p %{buildroot}/%{_docdir}
# don't copy ruby docs if they don't exist
[ -d build/bindings/ruby/html ] && cp -a build/bindings/ruby/html %{buildroot}/%{_docdir}/%{name}-ruby-docs

rm -f %{buildroot}/%{_libdir}/*.la
rm -f %{buildroot}/%{_libdir}/%{name}/plugins/*.la
rm -f %{buildroot}/%{_libdir}/%{name}/authenticators/*.la
[ -d %{buildroot}/%{ruby_sitelib} ] && rm -f %{buildroot}/%{ruby_sitelib}/openwsmanplugin.rb
[ -d %{buildroot}/%{ruby_vendorlib} ] && rm -f %{buildroot}/%{ruby_vendorlib}/openwsmanplugin.rb

%if 0%{?has_systemd}
install -D -m 644 %{S:4} %{buildroot}/%{_unitdir}/%{name}.service
%if 0%{?suse_version} < 1600
# rcopenwsman
ln -sf %{_sbindir}/service %{buildroot}/%{_sbindir}/rc%{name}
%endif
%else
# no systemd, assume sysv style init
mkdir -p %{buildroot}/%{_sysconfdir}/init.d
install -m 755 build/etc/init/openwsmand.sh %{buildroot}/%{_sysconfdir}/init.d/openwsmand
ln -sf %{_sysconfdir}/init.d/openwsmand %{buildroot}/%{_sbindir}/rcopenwsmand
%endif

%if 0%{?has_firewalld}
mkdir -p %{buildroot}/%{_prefix}/lib/firewalld/services
install -D -m 644 %{S:5} %{buildroot}/%{_prefix}/lib/firewalld/services/%{name}.xml
%else
install -D -m 644 %{S:3} %{buildroot}/%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}
%endif

#install -m 644 etc/%{name}.conf %{buildroot}/%{_sysconfdir}/%{name}
#install -m 644 etc/openwsman_client.conf %{buildroot}/%{_sysconfdir}/%{name}
#install -m 644 etc/ssleay.cnf %{buildroot}/%{_sysconfdir}/%{name}
#install -m 644 %{pamfile} %{buildroot}/%{_sysconfdir}/pam.d/%{name}

%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_pam_vendordir}
mv %{buildroot}/%{_sysconfdir}/pam.d/%{name} %{buildroot}/%{_pam_vendordir}
# for reproducible build:
strip-nondeterminism %{buildroot}/%{_javadir}/*jar
%endif

%if 0%{?rhel_version} == 700
rm -f %{buildroot}/%{_bindir}/winrs
%endif

%post -n libwsman1 -p /sbin/ldconfig
%postun -n libwsman1 -p /sbin/ldconfig

%post -n libwsman_client5 -p /sbin/ldconfig
%postun -n libwsman_client5 -p /sbin/ldconfig

%pre server
%if 0%{?has_systemd}
if [ -f /var/lib/systemd/migrated/%{name} ]; then
%service_add_pre %{name}.service
fi
%endif
%if 0%{?suse_version} > 1500
# Prepare for migration to /usr/lib; save any old .rpmsave
for i in pam.d/%{name} ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done

%posttrans server
# Migration to /usr/lib, restore just created .rpmsave
for i in pam.d/%{name} ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
echo Server certificates length must be 2048 bits or more. Check and recreate certificates if needed.
%endif

%post server
/sbin/ldconfig
%if 0%{?has_systemd}
%service_add_post %{name}.service
%else
%if 0%{?suse_version}
%{fillup_and_insserv openwsmand}
%else
# FIXME: chkconfig?!
%endif
%endif
%if 0%{?has_firewalld}
%firewalld_reload
%endif

%preun server
%if 0%{?has_systemd}
%service_del_preun %{name}.service
%else
%if 0%{?suse_version}
%{stop_on_removal openwsmand}
%else
# FIXME: chkconfig?!
%endif
%endif

%postun server
rm -f /var/log/wsmand.log
/sbin/ldconfig
%if 0%{?has_systemd}
%service_del_postun %{name}.service
%else
%if 0%{?suse_version}
%{restart_on_update openwsmand}
%{insserv_cleanup openwsmand}
%else
# FIXME: chkconfig?!
%endif
%endif

%post -n libwsman_clientpp1 -p /sbin/ldconfig

%postun -n libwsman_clientpp1 -p /sbin/ldconfig

%files -n libwsman1
%defattr(-,root,root)
%doc AUTHORS ChangeLog README.md TODO src/plugins/redirect/redirect-README
%license COPYING
%{_libdir}/libwsman.so.*
%{_libdir}/libwsman_curl_client_transport.so.*

%files -n libwsman_client5
%defattr(-,root,root)
%doc AUTHORS
%license COPYING
%{_libdir}/libwsman_client.so.*
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/openwsman_client.conf

%files -n libwsman-devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/pkgconfig/*
%{_libdir}/*.so
%exclude %{_includedir}/%{name}/cpp/*.h
%exclude %{_libdir}/libwsman_clientpp.so

%if 0%{?want_python3}
%files -n python3-%{name}
%defattr(-,root,root)
%{python3_sitearch}/*.so
%{python3_sitearch}/*.py*
%else

%files python
%defattr(-,root,root)
%{python_sitearch}/*.so
%{python_sitearch}/*.py*
%endif

# RHEL7 does not have ruby-devel
%if 0%{?rhel_version} != 700
%files ruby
%defattr(-,root,root)
%if 0%{?mandriva_version}
%{ruby_sitearchdir}/_openwsman.so
%dir %{ruby_sitelibdir}/%{name}
%{ruby_sitelibdir}/openwsman.rb
%{ruby_sitelibdir}/%{name}/*.rb
%else
%{ruby_sitearch}/_openwsman.so
%dir %{ruby_sitelib}/%{name}
%{ruby_sitelib}/openwsman.rb
%{ruby_sitelib}/%{name}/*.rb
%endif

%files ruby-docs
%defattr(-,root,root)
%dir %{_docdir}/%{name}-ruby-docs
%{_docdir}/%{name}-ruby-docs
# - endif not rhel-7
%endif

%files perl
%defattr(-,root,root)
%{perl_vendorarch}/%{name}.so
%{perl_vendorlib}/%{name}.pm

%if 0%{?suse_version} == 0 || 0%{?suse_version} >= 1100

%files java
%defattr(-,root,root)
%{_javadir}/*jar
%endif

%files server
%defattr(-,root,root)
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/ssleay.cnf
%attr(0755,root,root) %{_sysconfdir}/%{name}/owsmangencert.sh
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/%{name}
%else
%config %{_sysconfdir}/pam.d/%{name}
%endif
%if 0%{?has_firewalld}
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_prefix}/lib/firewalld/services/%{name}.xml
%else
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}
%endif
%if 0%{?has_systemd}
%{_unitdir}/%{name}.service
%if 0%{?suse_version} < 1600
%{_sbindir}/rc%{name}
%endif
%else
%attr(0755,root,root) %{_sysconfdir}/init.d/openwsmand
%{_sbindir}/rc%{name}d
%endif
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/authenticators
%{_libdir}/%{name}/authenticators/*.so
%{_libdir}/%{name}/authenticators/*.so.*
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/*.so
%{_libdir}/%{name}/plugins/*.so.*
%exclude %{_libdir}/%{name}/plugins/*ruby*.so*
%{_sbindir}/openwsmand
%{_libdir}/libwsman_server.so.*

# RHEL7 does not have ruby-devel
%if 0%{?rhel_version} != 700
%files server-plugin-ruby
%defattr(-,root,root)
%{_libdir}/%{name}/plugins/*ruby*.so
%endif

%files -n libwsman_clientpp1
%defattr(-,root,root)
%{_libdir}/libwsman_clientpp.so.*

%files -n libwsman_clientpp-devel
%defattr(-,root,root)
%{_libdir}/libwsman_clientpp.so
%dir %{_includedir}/%{name}/cpp
%{_includedir}/%{name}/cpp/*.h

# RHEL7 does not have ruby-devel
%if 0%{?rhel_version} != 700
%files -n winrs
%defattr(-,root,root)
%{_bindir}/winrs
%endif

%changelog
* Thu Jun 26 2025 pgajdos@suse.com
- added patches
  https://github.com/Openwsman/openwsman/commit/e619555c3484264a188396bc8b9c77c39ef47bb2
  + openwsman-gcc15.patch
* Wed Jan 22 2025 Klaus Kämpf <kkaempf@suse.de>
- Update to 2.8.1
  - openssl 3 requires 2048 bits as minimal key size, adapt key
    generation accordingly
  - Refresh README.md to reflect current options
  - revert minimal cmake version to 3.12 (Alexander Usyskin)
  - support reproducible builds (Bernhard Wiedemann)
  - properly report errors from openssl 3
* Sat Dec  7 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Use strip-nondeterminism to normalize jar mtimes for reproducible builds
* Thu Nov 28 2024 Klaus Kämpf <kkaempf@suse.de>
- Update to 2.8.0
  * Update to OpenSSL 3
  * Needs CMake 3.27 or later
  * Mostly compatibility and compiler warning fixes
  - builds on MacOS now (kkaempf)
  - updated to cmake 3.x (kkaempf)
  - fix usage of `facility` in logging (kkaempf)
  - fix Ruby rb_io vs rb_io_t to support Ruby 3.x (Vitezslav Crhonek, kkaempf)
  - Fixed missing void in prototypes causing compile errors when
    using -Wstrict-prototypes (Olaf Trygve Berglihn)
  - Removed unused token lineno causing errors due to compile
    flag -Wunused (Olaf Trygve Berglihn)
  - Link with libm for floor() function (Khem Raj)
  - Added wsman-key-value.h to list of headers to install (Olaf Trygve Berglihn)
  - wsman-win-client-transport: add SECURITY_FLAG_IGNORE_CERT_WRONG_USAGE,
    Ignore more problematic certificates if verify_peer is 0. (Alexander Usyskin)
  - unlock mutex before destroy (kkaempf)
  - fix many compiler warnings (Alexander Usyskin)
  - add Python 3.11 support (Joshua Kugler)
  - drop Python 3.7 support (kkaempf)
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Jan 16 2023 Stefan Schubert <schubi@suse.com>
- Migration of PAM settings to /usr/lib/pam.d.
* Wed Dec 28 2022 Klaus Kämpf <kkaempf@suse.com>
- Update to 2.7.2
  * Security
  - call setgroups before setuid or setgid (kkaempf)
  - harden systemd service (https://en.opensuse.org/openSUSE:Security_Features#Systemd_hardening_effort)
  * Bugfixes
  - wsman-win-client-transport: initialize certificate pointer (Alexander Usyskin)
  - iniparser: fix buffer size (Alexander Usyskin)
  - wsman-win-client-transport: plug leak in error path (Alexander Usyskin)
  - memory.c: fix memory cleanup (Alexander Usyskin)
  - Improve handling of HTTP 401 Unauthorized (Vitezslav Crhonek)
  - Fix serialization tests (kkaempf)
  - Fix Ruby bindings warnings (kkaempf)
  - Fix Ruby plugin loading test (kkaempf)
  - Fix rpm packaging (kkaempf)
  - Allow to run tests from 'build' directory (kkaempf)
  - Add Python XML test (kkaempf)
  - Enable CUNIT tests (kkaempf)
- drop openwsman-initscript.patch and harden_openwsman.service.patch
  (both upstream)
- add openwsman-redhat-initscript.patch
* Thu Apr 28 2022 Jan Engelhardt <jengelh@inai.de>
- Resolve rpmlint report "libwsman3.x86_64: E:
  shlib-policy-name-error SONAME: libwsman.so.1, expected package
  suffix: 1" (packaging bug introduced by the update to v2.6.1 on
  Aug 28 2015)
* Thu Apr  7 2022 Klaus Kämpf <kkaempf@suse.com>
- Update to 2.7.1
  Bugfix release
  * msvc build fixes (Alexander Usyskin)
  * cleanup passwords after use (Alexander Usyskin)
  * drop RANDFILE in owsmangencert.h (kkaempf)
  * fix potential NULL pointer dereference (Alexander Usyskin)
  * MinGW build enablement (Bastian Germann)
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_openwsman.service.patch
  Modified:
  * openwsman.service
* Mon Aug 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Use more appropriate %%{_prefix}/lib for firewalld service
  definitions (boo#1174075).
* Mon May 25 2020 Klaus Kämpf <kkaempf@suse.com>
- Update to 2.7.0
  * API change:
    client_opt: expiry and hearbeat_interval are float (Alexander Usyskin)
    wsmc_set_sub_expiry() and wsmc_set_heartbeat_interval() change their
    first parameter from int to float
  * bump so version of libwsman_client from 4 to 5
  * split off client libraries from server libraries
    libwsman_client5 is separate from libwsman3 now.
- Features
  * new functions for C++ bindings: OpenWsmanClient::GetWithFlags()
    and OpenWsmanClient::PutWithFlags to add a 'flags' parameter
    (Alexander Usyskin)
  * add FLAG_SUPRESS_100_CONTINUE to options, fixes #131 to workaround
    a curl problem. Reportedly curl 7.69.0 fixes this also in curl.
    (Alexander Usyskin)
- Fixes
  * fixed several compiler warnings (Alexander Usyskin)
  * fixed spelling errors (Tomas Winkler)
* Fri Oct  4 2019 Klaus Kämpf <kkaempf@suse.com>
- Update to 2.6.13
  * Bugfixes
  - fixed several compiler warnings (Alexander Usyskin)
  - code cleanup (Alexander Usyskin)
  - general code robustness (Alexander Usyskin)
* Tue Sep 17 2019 Klaus Kämpf <kkaempf@suse.com>
- Update to 2.6.12
  * Bugfix release
  - fix regression from 2.5.0: __cimnamespace selector was not
    properly set in requests.
* Tue Sep 17 2019 Klaus Kämpf <kkaempf@suse.com>
- Update to 2.6.11
  * Bugfix release
  - prevent double free in events error processing
* Wed Aug  7 2019 Klaus Kämpf <kkaempf@suse.com>
- Update to 2.6.10
  * install firewalld configuration (Leap/SLE 15+, Fedora 15+)
  * Fix possible denial of service (bsc#1122623, CVE-2019-3816, CVE-2019-3833)
  * Pthread usage fixes (Alexander Usyskin)
  * Convert sprintf to snprintf and strcpy to strncpy (Tomas Winkler)
  * Many potential NULL dereferences fixed (Alexander Usyskin)
- drop bsc1122623.patch and debug_fix.patch, upstreamed
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Wed Apr  3 2019 Adam Majer <adam.majer@suse.de>
- bsc1122623.patch: (bsc#1122623, CVE-2019-3816, CVE-2019-3833)
  + treat all non-registered by provider paths as invalid
  + fix possible denial of service in path parsing
- debug_fix.patch: fix compilation in debug mode
- use OBS specific BuildIgnore syntax that is rpm friendly. This is
  to prevent rpm parser from reporting errors.
* Tue Jan  8 2019 olaf@aepfle.de
- Remove comment from postun scriptlet because it generates a
  script which is not understood by specified interpreter
* Mon Nov 19 2018 Klaus Kämpf <kkaempf@suse.com>
- Update to 2.6.9
- Build with CURL 7.62.0 or later
- Fix VS 2017 compilation (#114)
- Warn on empty ssl_cipher_list (#111)
* Fri Oct 12 2018 Klaus Kämpf <kkaempf@suse.com>
- Update to 2.6.8
- Disable directory listing in the http(s) component
- Switch license to BSD-3-Clause AND GPL-2.0-only, since redirect
  plugin is under GPL 2.0 only license.
* Sun Mar  4 2018 jengelh@inai.de
- Update RPM groups and package descriptions.
- Replace old $RPM_* shell vars. Remove some unnecessary
  %%if..%%endif blocks that do not affect the build process or
  result.
* Thu Feb 22 2018 fcrozat@suse.com
- Switch license to BSD-3-Clause AND GPL-2.0-only, since redirect
  plugin is under GPL 2.0 only license.
* Mon Feb 19 2018 kkaempf@suse.com
- Update to 2.6.7
  - Features
  - Build with CMake 2.6 or later
  - Bugfixes
  - fix return value check for SSL_CTX_set_cipher_list()
  - fix pam config for local install
* Wed Dec 13 2017 kkaempf@suse.com
- python3-openwsman
* Mon Dec 11 2017 kkaempf@suse.com
- fix Source declarations to get a complete src.rpm
* Tue Dec  5 2017 kkaempf@suse.com
- Build Python3 on Leap and SLE 15
- Fix RHEL7 build
* Mon Dec  4 2017 kkaempf@suse.com
- update to 2.6.6
  - openssl 1.1.0 compatibility
  - build python3 or python2 binding, but not both
* Fri Nov 24 2017 kkaempf@suse.com
- update to 2.6.5
  - Fix python3 / ruby 2.5 compatibility
  - drop openwsman-2.6.2-python3.patch
* Wed Nov  8 2017 kukuk@suse.de
- Replace obsolete pam modules with standard ones
* Tue Nov  7 2017 kkaempf@suse.com
- update to 2.6.4
  - Bugfixes
  - setup ECDHE to allow Perfect Forward Secrecy, using the p256
    NIST prime curve (CVE-2016-2183) (mmeissner)
* Sat Sep  9 2017 kgronlund@suse.com
- Package for python 3
- Add openwsman-2.6.2-python3.patch
* Sun Apr 30 2017 bwiedemann@suse.com
- use strip-nondeterminism to make build more reproducible
* Mon Jun 20 2016 kkaempf@suse.com
- update to 2.6.3
  - Bugfixes
  - Prevent buffer overflow if digest realm too long
  - Ensure path starts with '/' in client data endpoint
  - Java bindings build fix
  - Fix SSL library, usage is not thread safe (vcrhonek)
  - Improve NetBSD and OSX builds (apjanke)
  - Install winrs with correct name and permissions
* Thu Dec  3 2015 kkaempf@suse.com
- make winrs executable
  add-shebang-to-winrs.patch
* Wed Dec  2 2015 srinidhi.bs@microfocus.com
- Install winrs with executable permissions
* Wed Oct  7 2015 kkaempf@suse.com
- Update to 2.6.2
  - Features
  - Install winrs.rb (Windows Remote Shell) to /usr/bin
  - New package: winrs
  - Bugfixes
  - Make iniparser thread-safe (Emil Bartczak)
  - Fix excessive RPM rebuilds (Olaf Hering)
  - Fix selector extraction from URI query (Markus Kolb)
  - Fix RPM building on older distributions
  - Fix RPM building on Fedora 22
* Mon Oct  5 2015 kkaempf@suse.com
- Fix build for older distributions.
  Add struct-epr.diff
* Fri Aug 28 2015 kkaempf@suse.com
- Update to 2.6.1
  - Features
  - Add curlopt_nosignal option to openwsman_client.conf to prevent
    CURL crashes in multithreaded client applications
  - Limit EnvelopeSize to 32767 if wsman:MaxEnvelopeSize not set in
    request (WS-Man 1.2 compatibility) (Prabhakar Pujeri)
  - Bugfixes
  - fix memory leaks (Vitezslav Crhonek)
  - honor client:agent from openwsman_client.conf
  - fix possible crash in dictionary_get()
* Tue Jun 16 2015 kkaempf@suse.com
- fix SLE 10 & 11 builds
* Thu Jun 11 2015 kkaempf@suse.com
- Update to 2.6.0
  - Features
  - Implement DSP 0226 Section 6.3 wsman:Locale
    (wsmc_set_locale, wsmc_get_locale)
  - set transport timeout for c++ binding (prabhakar_pujeri@dell.com)
  - print CIMError code in HTTP header (prabhakar_pujeri@dell.com)
* Wed Jun  3 2015 kkaempf@suse.com
- Update to 2.5.2
  - Features
  - build native Python package (Ahmad Jagot)
  - Cleanup
  - remove (unused) 'min_threads' config option (Vitezslav Crhonek)
* Wed Jun  3 2015 kkaempf@suse.com
- Update to 2.5.1
  - Features
  - adds RFC1866 support in allowing ; as a separator for
    resource uri query parameters (selectors).
  - print a warning if a resource URI (wrongly) uses ',' as
    query parameter separator.
* Wed May 20 2015 kkaempf@suse.com
- Update to 2.5.0
  - Drop 'openwsmand' service name, use 'openwsman' only
    (was never properly supported by systemd anyways)
  - Features
  - Rewrite selector and property handling to keep
    them in order (#49)
    Selectors and properties can now handle EndpointReferences
    as values. This increases compatibility with Intel AMT 7.0
    and later.
  - ABI change, .so version 3
  - Ruby: Add EndPointReference#to_s
* Wed May 20 2015 kkaempf@suse.com
- Update to 2.4.15
  - Features
  - Ruby: Add Fault#to_s
  - Ruby: Enable ClientOptions#properties=
  - Cim: New config option "cim_client_cql' to select CQL query
    identifier ('CQL' - default, 'DMTF:CQL' - standards-compliant)
  - Bugfixes
  - Fix segfault in wsmc_add_property
  - Fix memleak in xpath handling
  - Fix typo in parsing max_connections_per_thread (vcrhonek)
  - Ruby: ClientOptions#properties=
* Tue Feb 24 2015 kkaempf@suse.com
- Update to 2.4.14
  - Features
  - Improved C++ bindings (Peter Hatina)
  - Bugfixes
  - Build fixes for Fedora21, RHEL7, and CentOS7
  - option parser accepts '-?' and '--help' as valid
* Wed Jan 21 2015 kkaempf@suse.com
- Fix Fedora 21, RHEL 7, and CentOS 7 build
* Thu Jan 15 2015 kkaempf@suse.com
- Update to 2.4.13
  - Features
  - Support Ruby 2.2
  - Bugfixes
  - Parsing of vendor namespaces (#48, #38)
  - Client getters memory leaks (#47)
  - Keep order of 'invoke' parameters (#49)
* Wed Oct 29 2014 kkaempf@suse.com
- check SSL version
* Tue Oct 28 2014 kkaempf@suse.com
- Update to 2.4.12
  - Features
  - New config option 'ssl_disable_protocols'. Pre-set to disable
    SSLv2 and v3 in SSL mode
  - Ruby: support Ruby 2.1 threading API
  - Bugfixes
  - Fix memory corruption due to a malloc made with the wrong size
  - iniparser: dictionary_set' must return a value (David Holm)
- drop fix-memory-corruption.patch, upstream
* Wed Sep 17 2014 kkaempf@suse.com
- call service_add_pre unconditionally
* Fri Sep 12 2014 kkaempf@suse.com
- Fix possible memory corruption
  Add fix-memory-corruption.patch
* Fri Aug  1 2014 kkaempf@suse.com
- Update to 2.4.11
  - Features
  - Bindings: EndPointReference.selector_names() for Python
  - Bugfixes
  - URI parsing: Disallow comma to separate selectors in resource
    uri, only ampersand is allowed. (issue #38)
  - Bindings: Fix Ruby doc generation
* Fri Jul 25 2014 kkaempf@suse.com
- Update to 2.4.10
  - Feature
    Allow to pass EndPointReference instances as invoke() parameters
    via ClientOptions.add_property
* Mon Jun 30 2014 kkaempf@suse.com
- Update to 2.4.9
  - Bugfixes
    Make finding libssl.so.* more robust (bnc#884965)
* Fri Jun 20 2014 kkaempf@suse.com
- Update to 2.4.8
  - Features
  - Add Fujitsu namespace, cim schema SVS
  - Bugfixes
  - fix memory corruption: copy key/value data for options,
    selectors, and properties
  - fix .spec file for RHEL/Fedora builds
* Wed May 21 2014 kkaempf@suse.com
- Update to 2.4.7
  - Bugfixes
  - file authenticator: allow password hash of up to 128 characters
  - libu: don't exit() on malloc errors
* Tue May 20 2014 kkaempf@suse.com
- Update to 2.4.6
  - Features
  - Support large hashes (like SHA512) in file authentication
  - use constant-time password compare to prevent brute-force attacks
  - Create server-plugin-ruby as separate RPM
  - Add Unisys namespace and CIM class prefix 'SPAR'
  - Bugfixes
  - Fix crash on invalide resource URI
  - Fix resource namespace for DCIM_ classes
* Wed May  7 2014 kkaempf@suse.com
- Split off server-side Ruby plugin to openwsman-server-plugin-ruby
- Alias systemd service openwsman to openwsmand, add respective
  rcopenwsman and rcopenwsmand commands.
* Fri Mar 14 2014 kkaempf@suse.com
- Update to 2.4.5
  - Features
  - enforce SSL operation in systemd service
  - Add /usr/sbin/rcopenwsman for systemd environments
  - New environment variable 'OPENWSMAN_CURL_TRANSPORT_SSLVERSION' to
    select SSL protocol version. Set it to 'tlsv1.2' for TLS-v1.2
    (anstein)
  - Bugfixes
  - Fix memory leaks in redirect plugin (Praveen K Paladugu)
  - shttpd: Improve error reporting if SSL context fails
  - Builds on Fedora 20 now
* Thu Feb 27 2014 kkaempf@suse.com
- Update to 2.4.4
  - Security update
  - ws_xml_make_default_prefix() can overflow buf parameter via sprintf()
  - ws_xml_make_default_prefix() can overflow buf parameter via sprintf()
  - wsmc_create_request() potential buf[20] overflow via WSMAN_ACTION_RENEW
  - LocalSubscriptionOpUpdate() unchecked fopen()
  - Incorrect order of sanity guards in wsman_get_fault_status_from_doc()
  - Unchecked memory allocation in wsman_init_plugins(), p->ifc
  - Unchecked memory allocation in mem_double(), newptr
  - Unchecked memory allocation in dictionary_new(), d, d->val, d->key, d->hash
  - Unchecked memory allocation in u_error_new(), *error
  - sighup_handler() in wsmand.c uses unsafe functions in a signal handler
  - Features
  - add rcopenwsman command to systemd environments
  - Bindings
  - support rdoc 2.1 in Ruby bindings
  - cmake: use PYTHON_INCLUDE_DIRS
* Wed Jan 29 2014 kkaempf@suse.com
- add 'rcopenwsmand' for systemd-based distributions
* Tue Dec 10 2013 kkaempf@suse.com
- Update to 2.4.3
  - Fix bindings for Java 1.5
  - Raise exception if client creation fails (bindings)
* Mon Oct 14 2013 kkaempf@suse.com
- Update to 2.4.2
  - Fix crash in redirect module (typo)
  - Honor WS-Management 1.1.1 standard (line 739):
    disable multiple MessageID checks
* Wed Sep 11 2013 kkaempf@suse.com
- Update to 2.4.1
  - Fix build for SLE11, Fedora 18 & 19
  - Fix build time test library path
  - include version.rb into ruby gem (fixes issue #18)
* Thu Sep  5 2013 kkaempf@localhost
- Update to 2.4.0
  - Features
  - Add support for OptionSet in SOAP header (breaks ABI)
  - Increase soversion of libwsman_client to 2.0.0
  - new function wsmc_add_option
  - Redirect plugin: Added facilities to import the redirection
    details from an included file (Praveen K Paladugu)
  - Bugfixes
  - wsman_transport_set_verify_host passed wrong values to CURL
  - recognize 'Msvc' (Hyper V) and 'DCIM' (Dell Drac) CIM schemata
  - xml_parser_element_dump: fix pointer (github issue #8)
  - Bindings
  - Support for OptionSet
  - ClientOptions#add_option
  - ClientOptions#options= (Ruby)
  - XmlDoc#to_s returns non-indented xml representation
  - Define security delivery modes (WSMAN_DELIVERY_SEC_*)
  - Ruby: API change: Transport.verify_{host,peer}? return Boolean now
    Transport.verify_peer -> Transport.verify_peer?
    Transport.verify_host -> Transport.verify_host?
  - Ruby: Fix Ruby 1.9 threading locks for wsmc_action_* functions
  - Ruby: Accessors for OptionSet, Selectors, and Properties
  - ClientOptions#options
  - ClientOptions#properties
  - ClientOptions#selectors
  - Vastly improved bindings documentation
    Splitted off openwsman-ruby-docs subpackage
  - Generate documenation with rdoc matching Ruby version
  - Windows Remote Shell client implementation (see ruby/tests/winrs.rb)
* Thu May 30 2013 kkaempf@suse.com
- Fix Fedora 18 and SLE10 builds
- Drop rubygem build require, we build rpm not gem here.
* Thu Feb 21 2013 kkaempf@suse.com
- Update to 2.3.7
  - Bugfixes
  - Generate pkgconfig (.pc) files correctly
  - Require SWIG > 2.0.4 for building
* Tue Feb 19 2013 kkaempf@suse.com
- fix %%post script
* Wed Oct 10 2012 kkaempf@suse.com
- Update to 2.3.6
  - Features
  - Plugins: Ability to redirect requests to a different WS-Management
    server (Praveen Paladugu)
  - Bugfixes
  - Fix xml namespace in Fault message (Praveen Paladugu)
  - Pass correct key values when creating a Cim_IndicationSubscription
    (Santosh Bidaralli)
  - verify_class_namespace: properly check for 'CIM' class schema
    (Mayur Bhosle)
  - Fix MaxElements namespace in Pull context (Praveen Paladugu)
  - Bindings
  - Ruby: fix crash in Options destructor
  - Ruby: mark passing arrays via invoke as unsupported
  - Building
  - new cmake option: BUILD_BINDINGS (defaults to yes)
  - honor BUILD_TESTS for all test directories
  - fix MaxcOS build (Dan Villiom Podlaski Christiansen)
* Sat Aug 11 2012 kkaempf@suse.com
- fix building for non-SUSE distros, re-add java target for SLES10
- disable ruby on RHEL6 (missing ruby-devel)
* Wed Aug  8 2012 kkaempf@suse.com
- improve FindRuby, fixes CentOS5 and RHEL5 builds
* Fri Jun 22 2012 mvyskocil@suse.cz
- removes explicit and unecessary -target argument for javac
* Fri Jun  1 2012 kkaempf@suse.com
- Update to 2.3.5
  - Release serializer lock only after use (satya.chittidi@emc.com)
* Tue May 29 2012 kkaempf@suse.com
- Fix ruby(abi) require
* Mon May 28 2012 kkaempf@suse.com
- Update to 2.3.4
  * Adapt to Swig 2.0.7
  - renamed construtors/destructors.
  - SwigClass.. variables are static now
* Sat May 26 2012 kkaempf@suse.com
- Require ruby(abi) = 1.9.1 for openSUSE > 12.1
* Fri May 25 2012 kkaempf@suse.com
- Update to 2.3.3
  - Bugfixes
  - Fixed enumeration with selector filter returning only one
    instance. (Zoltan Micskei)
  - mark XPath filtering as not supported (in sfcc)
  - Bindings
  - Adapt to Ruby 1.9
  - Disable RDoc for Ruby 1.9
  - WsXmlDoc.to_xml - enforce utf-8 encoding
  - Properly create AssociationInstances(CIM References) /
    AssociatedInstances(CIM Associations) filter
- Update to 2.3.2
  - Bugfixes
  - Assume 'XPath' as default filter dialect, not 'WQL' (Zoltan Micskei)
  - Bindings
  - Add ClientOptions#flags() (read) and ClientOptions#reset_flags()
  - Add Openwsman#uri_prefix
  - Add Openwsman#create_doc_from_string
  - Provide full EndPointReference handling
- Update to 2.3.1
  - Features
  - switch default CIMOM connection to https on port 5989
    with PAM authentication (this now reflects the default sfcb config)
  - Bindings
  - Ruby: Add Openwsman#epr_uri_for
  - Bugfixes
  - Fix build issues in .spec file
* Thu Mar  8 2012 kkaempf@suse.com
- Fix systemd %%pre issues on openSUSE
* Tue Mar  6 2012 kkaempf@suse.com
- Disable building of Ruby GEM in .spec file
- Add perl-devel for CentOS6 and RHEL6
- Provide systemd support in Fedora 15
* Wed Feb 22 2012 kkaempf@suse.com
- Update to 2.3.0
  Features
  - openSUSE: support systemd
  - provider getter functions for all client and client option string
    values
  - Add ssl-related config options in [cim] section, see openwsman.conf
    ssl = yes/no
    verify_cert = yes/no
    trust_store = /etc/ssl/certs
  Bugfixes
  - Enum/Pull: Fix envelope maxsize handling, return partial result
  - Fix memleaks in client and client option string setters
    (Matthias Bolte)
  - All string value getters (for client and client_opt) return
    copies now
    (found by Matthias Bolte)
  - Define and use PLUGIN_API_VERSION for the server-side plugins
  - Handle optional arguments propertly during client endpoint URI
    creation (Matthias Bolte)
  - Make calls to 'identify' repeatable
  - Destroy serializer lock and client mutex at exit (Bing Liu)
  - Fix leak in wsmc_release (Sanjeev Putta)
  - Allow to reset transport credentials to NULL (Matthias Bolte)
  - Plug memory leaks in wsman-client-transport (Found by Suneet
    Chandok, improved by Matthias Bolte)
  - print warning if event delivery fails
  Bindings
  - Provide Ruby bindings also as GEM
    (-> https://rubygems.org/gems/openwsman)
  - Add Openwsman#create_doc_from_file to read xml files
  - Add XmlNode#next to iterate over children with identical name
  - Add Openwsman#erb_prefix_for to return EPR uri prefixes for
    different CIM schema
  - Ruby: Provide a default implementation of auth_request_callback
  - Ruby: Support Ruby 1.9
  - Expose Openwsman version as OPENWSMAN_VERSION, OPENWSMAN_MAJOR,
    OPENWSMAN_MINOR, OPENWSMAN_PATCH
  - Ruby: expand XmlNode#each to iterate over multiple children of
    same name
  - new test tool: winenum.rb, to enumerate WINRM instances
  - update documentation: Add note about escaping selector values
* Tue Jan 24 2012 joop.boonen@opensuse.org
- Corrected the license
- Corrected the formating according to the openSUSE standard
* Tue Dec  6 2011 aj@suse.de
- Do not package files twice.
* Fri Sep  9 2011 kkaempf@suse.com
- Update to 2.2.7
  - Features
  - Rename openwsman-client to libwsman_clientpp since it only
    includes C++ bindings. Split off libwsman_clientpp-devel.
    Move openwsman_client.conf to libwsman1.
  - Performance improvements for Enum (optimized) and Pull requests
    (Srinivas Thirumalaa)
  - Bindings
  - Fix all tests
  - Enhance client function documentation
  - Add max_elements, max_envelope_size, fragment, and timeout
    to Options
  - Use optimized enumeration in tests
  - Bugfixes
  - Fix memory leaks in wsmc_action_enumerate_and_pull and wsmc_release
    (Matthias Bolte)
  - Fix possible corruption in ws_serializer_free_mem
    (Matthias Bolte)
  - Fix recognition of ntlm and gss-negotiate auth methods when checking
    server-requested vs. client-offered methods.
  - Developer
  - Enable client tests
  - Improve Windows build (Matthias Bolte)
  - Reduce libu exposure in the public API (Matthias Bolte)
* Wed Apr 20 2011 kkaempf@novell.com
- Update to 2.2.6
  - Features
  - Add array support for indications (Suresh Sundriyal)
  - Add indication_baseclass_namespace (Till Steinbach, Suresh Sundriyal)
  - Bugfixes
  - Correctly prefix /etc when CMAKE_INSTALL_PREFIX is not /usr (Chris Poblete)
* Mon Feb 14 2011 kkaempf@novell.com
- Disable SSL callback on Fedora (curl-Bugs-1924441)
* Mon Jan  3 2011 kkaempf@novell.com
- Update to 2.2.5
  - Restrict use of wsman:MaxElements to wsman:OptimizeEnumeration
  - Fix owsmangencert.sh pathes
  - Improve CMake variable handling
* Wed Sep 29 2010 kkaempf@novell.com
- Update to 2.2.4
  - Build with cmake
  - add -java subpackage (not for SLES10)
  - enforce manual creation of certificate (to get sufficient
    entropy for randomness) (Praveen Paladugu)
* Fri Sep 10 2010 kkaempf@novell.com
- fix pam config on RHEL/Fedora
* Wed Jun  9 2010 kkaempf@novell.com
- 2.2.3.9 Bugfix release:
  - bindings (kkaempf)
  - make all constants uppercase
  - pass code, code_detail, and message to WsmanStatus()
    constructor optionally
  - Pass XmlDoc to Fault() constructor
  - Fix exceptions for Perl and Python
  - Ruby: Alias XmlDoc.foo to XmlDoc.body.foo
  - Ruby: Create bindings documentation
  - Java: Enable and fix for JDK 1.6 (kkaempf + jblunck)
  - Fix Fedora/RH build (kkaempf)
  - Use floor() instead of round() (Suresh Sundriyal)
  - Reuse username/password if auth_request_func is not set (Arun
    Venkatachalam)
  - Catch invalid reference parameters (report bad EPR values)
    (kkaempf)
  - fix Windows build (Trevor Witten)
  - fix ssl (certificate thumbprint) callback check (Arun
    Venkatachalam)
* Mon Apr 26 2010 kkaempf@novell.com
- Fix segfault on invalid reference parameters to method calls.
  bnc#599658
* Wed Apr 21 2010 kkaempf@novell.com
- Check rc.msg pointer before accessing it through CMGetPointer
* Mon Apr 19 2010 kkaempf@novell.com
- Fix dynamic loading of ssl lib (bnc#574684)
* Wed Mar 10 2010 kkaempf@novell.com
- Fix ssl certificate thumbprint callback issue
  (Arun Venkatachalam, bnc#587348)
* Thu Feb 25 2010 kkaempf@novell.com
- Updated to 2.2.3 final release
  - cleanup: access CMPIString by macro, not by casted direct
    member access
  - fix connection error msg: rc.msg is a CMPIString, not a char*
    (kkaempf)
  - fix for OperationTimeout parsing (Chris Poblete)
* Mon Feb 22 2010 kkaempf@novell.com
- Updated to 2.2.3 pre-release
  - fix Windows build (forum.openwsman.org)
  - fix to build with non-standard subscriptions dir (Chris Poblete)
  - accept OperationTimeout values as outlined in Section 3.2.6.1
    of http://www.w3.org/TR/xmlschema-2 (Chris Poblete)
  - fall back to IPv4 if IPv6 unsupported (Arun Venkatachalam)
  - make IPv4 vs. IPv6 configurable (kkaempf)
  - support invoking a method with array type parameter/arguments
    (Chris Poblete, bnc#581414)
  - fix crash in (unhandled) Array argument (Suresh Sundriyal)
  - handle MaxElements in Pull operations (Chris Poblete, kkaempf,
    bnc#581731)
  - fix building with ssl when openssl/ssl.h is available
    (Chris Poblete)
  - make plugin directory configurable (Chris Poblete)
  - fix "WXF Invalid Representation" error when sending a Create
    instance request  using the WinRm client (Trevor Witten)
* Thu Jan 21 2010 kkaempf@novell.com
- Update to 2.2.2 bugfix release
  - fix init.d script to run on non-LSB systems (bnc#571873)
  - Clean up CMake build
  - More build fixes for RHEL5, Fedora 11+12, CentOS 5
  - Fix host certificate check in eventing, enable only if the
    verify_host flag is set (bnc#569611)
  - fix NULL pointer dereference in PullResponse (bnc#572553)
  - adapt bindings to Swig 1.3.40
  - fix setters in bindings
* Thu Jan 14 2010 kkaempf@novell.com
- fillup_and_install is for SUSE only, remove in .spec for others
* Tue Nov 24 2009 kkaempf@novell.com
- re-add openwsman.SuSEfirewall2 and openwsman.pam
* Thu Nov 19 2009 kkaempf@novell.com
- Update to 2.2.1
- Major changes:
  - Enumeration timeout fixed, resulting in --enum-idle-timeout option
    to openwsmand taking seconds (instead of miliseconds) now
  - Client side CRL (certificate revocation list) support
    (Arun Venkatachalam)
  - split off client config as /etc/openwsman/openwsman_client.conf
  - Fix upper limit check for threads and their stack usage (Suresh Sundriyal)
    (Allowing to confine memory usage in the 10-20MB range!)
    Reintroduce max_thread config file parameter and two new parameters
  * max_connections_per_thread
  * thread_stack_size
- Minor changes:
  - require swig 1.3.30 or later (rhel5 users: upgrade !)
  - clean up fault generation in CIM backend (Suresh Sundriyal)
  - fix various memory leaks (Suresh Sundriyal)
  - fix Python bindings build (kkaempf)
  - Fix security risk when listing indication subscriptions (Suresh Sundriyal)
  - Fix xml namespace for enumeration and subscription filters (kkaempf)
  - Fix class names for swig bindings, makes Python bindings
    operational (kkaempf)
  - Use same encoding for faults as in incoming msg (bug305, kkaempf)
  - Make WS-Enumeration pull response comply to WS-Enumeration sequence
    ordering (bug220, Suresh Sundriyal)
- Fix build for Fedora 11.x, 12.x, and RHEL 5.x
* Thu Nov 19 2009 mhrusecky@suse.cz
- updated to the version 2.2.0
  - Major changes:
  - Adapt IANA ports of 5985 (http) and 5986 (https)
  - Change the Ruby bindings module name to 'Openwsman'
  - Change the Ruby plugin module name to 'Openwsman'
  - IPv6 support
  - preliminary support for wbem intrinsic operations
    'EnumerateClassNames' and 'GetClass'
  - Perl client bindings
  - Minor changes:
  - Perl example code added (by warptrosse@gmail.com)
  - Fixes to the CMake build environment
  - Fixes to the sfcc backend (argument handling, xml escaping)
  - Many other bug fixes, e.g.
    297: More detailed http status codes
    309: Use correct namespace for detecting Filter node
    288: CIM Provider Faults not getting propagated to client
    279: Openwsman server is adding extra CRLF
- longer description
* Thu Oct 29 2009 kkaempf@suse.de
- fix build for SLE9, 10, and 11.
* Thu Oct 15 2009 mhrusecky@suse.cz
- using official ports 5985 and 5986 by default (fate#306512)
- SuSE Firewall configuration
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Wed Jul 15 2009 puzel@novell.com
- Fix build with automake-11.1
  - openwsman-2.1.0-automake_fix.patch
* Fri Jan 23 2009 prusnak@suse.cz
- fix cyclic dependencies of packages [bnc#467956]
- fixed SSL/invoke method (ssl_fix.patch and invoke_fix.patch)
* Thu Nov  6 2008 kkaempf@suse.de
- Fix possible segfault (bnc#442327)
* Tue Sep 16 2008 prusnak@suse.cz
- updated to 2.1.0
  * Security related fixes
  * Many bug fixes related to http stack
  * GSSAPI support (thanks to Paul Moore)
- updated to 2.0.1
  * Added Java bindings
  * Set proxy in C++ bindings
  * Fixed SelectorSet Filter
  * Added SelectorSet filter support to C++ interface
  * SelecorFilter does not need __cimnamespace
- dropped obsoleted patch:
  * interim-bug-fixes.patch (included in update)
* Thu May  8 2008 schwab@suse.de
- Fix configure script.
* Tue Apr 22 2008 prusnak@suse.cz
- update to 2.0.0
  * Use latest shttpd code base
  * Fixed SSL related issues with shttpd
  * Ruby bindings using swish now and part of openwsman
  * Python bindings update
  * serialize/de-serialize APIs updated
    Make serialize/de-serialize APIs independent of server related structure
  * secure eventing delivery support in WS-Eventing server code and related
    options added in client code.
  * WS-Eventing client interfaces updated to make it more general
  * Source indication namespace configuration supported so that the
    namespace of subscription related classes can be different from
    that of indication class
  * Anonymous identify and custom identify file supported
  * Support SelectorSet Dialect
  * Improved Filter API
  * Improved EPR API
  * Enahnced bindings to support filters
  * Initial cmake support
  * Many other bug fixes
* Thu Jan 24 2008 prusnak@suse.cz
- added libopenssl-devel to BuildRequires
* Wed Dec 19 2007 kkaempf@suse.de
- update to svn 2336
  * added and enabled ruby bindings
  * custom and anonymous Identify support added
- new sub-packages: openwsman-ruby, openwsman-python
- add rpmlintrc for .so files within openwsman-server
* Fri Dec 14 2007 kkaempf@suse.de
- update to 1.5.9 (svn 2314) in preparation of 1.6.0
- enable python bindings
* Mon Nov 12 2007 prusnak@suse.cz
- update to 1.5.1
  * Fixed crash in CIM plugin
  * Fixed serialization in client library
* Tue Nov  6 2007 prusnak@suse.cz
- update to 1.5.0
  Openwsman 1.5 is an interim stable release toward 2.0 with all
  completed features since 1.0. This release serves as a checkpoint
  to evaluate implemented and outstanding features and to take care
  of bugs instead of waiting until the beta phase of 2.0.
  See ChangeLog for more details ...
- fixed installdirs (mkinstalldir.patch)
- added entries to ChangeLog from wiki (changelog.patch)
- renamed openwsman to libwsman1 and openwsman-devel to libwsman-devel
- removed obsolete patches
  * devel.patch (included in update)
  * get_auth.patch (included in update)
  * remote_fs.patch (included in update)
* Fri Aug  3 2007 kkaempf@suse.de
- update to 1.2.0
- default to pam authentication in openwsman-server
- fix filelist (include .so files for plugin loading)
- fix %%preun for base package
- remove wsmand.log when deleting openwsman-server
- fix -devel dependencies
- add wsman_transport_get_auth_method() definition
* Tue Jul 24 2007 prusnak@suse.cz
- branch packages -server and -client
- replaced obsoleted macro %%run_ldconfig with direct call of ldconfig
- added $remote_fs to Required-Start in init file (remote_fs.patch)
* Fri Jul 13 2007 prusnak@suse.cz
- created package (version 1.1.0)
- based on BuildService package openwsman in home:nashif
